@@ -13,7 +13,11 @@ Early stopping callbacks
 ------------------------
 * DeltaXStopper
 """
-from collections import Callable
+try:
+    from collections.abc import Callable
+except ImportError:
+    from collections import Callable
+
 from time import time
 
 import numpy as np
